@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -120,7 +120,7 @@ class HelpTabWidget(E5TabWidget):
         self.__closeButton.setToolTip(
             self.tr("Close the current help window"))
         self.__closeButton.setEnabled(False)
-        self.__closeButton.clicked[bool].connect(self.closeBrowser)
+        self.__closeButton.clicked.connect(self.closeBrowser)
         self.__rightCornerWidgetLayout.addWidget(self.__closeButton)
         if Preferences.getUI("SingleCloseButton") or \
            not hasattr(self, 'setTabsClosable'):
@@ -137,7 +137,7 @@ class HelpTabWidget(E5TabWidget):
         self.__newTabButton.setToolTip(
             self.tr("Open a new help window tab"))
         self.setCornerWidget(self.__newTabButton, Qt.TopLeftCorner)
-        self.__newTabButton.clicked[bool].connect(self.newBrowser)
+        self.__newTabButton.clicked.connect(self.__newBrowser)
         
         self.__initTabContextMenu()
         
@@ -288,6 +288,13 @@ class HelpTabWidget(E5TabWidget):
         browser = self.widget(self.__tabContextMenuIndex)
         self.printPreviewBrowser(browser)
     
+    @pyqtSlot()
+    def __newBrowser(self):
+        """
+        Private slot to open a new browser tab.
+        """
+        self.newBrowser()
+    
     def newBrowser(self, link=None, requestData=None, position=-1):
         """
         Public method to create a new web browser tab.
@@ -431,6 +438,7 @@ class HelpTabWidget(E5TabWidget):
             browser = self.widget(index)
             browser and browser.reload()
     
+    @pyqtSlot()
     def closeBrowser(self):
         """
         Public slot called to handle the close action.
@@ -450,19 +458,32 @@ class HelpTabWidget(E5TabWidget):
         
         @param index index of browser to close (integer)
         """
-        urlbar = self.__stackedUrlBar.widget(index)
-        self.__stackedUrlBar.removeWidget(urlbar)
-        del urlbar
-        
         browser = self.widget(index)
         if browser is None:
             return
         
+        if browser.isModified():
+            ok = E5MessageBox.yesNo(
+                self,
+                self.tr("Do you really want to close this page?"),
+                self.tr("""You have modified this page and when closing it"""
+                        """ you would lose the modification.\nDo you really"""
+                        """ want to close this page?"""))
+            if not ok:
+                return
+        
+        urlbar = self.__stackedUrlBar.widget(index)
+        self.__stackedUrlBar.removeWidget(urlbar)
+        urlbar.deleteLater()
+        del urlbar
+        
         self.__closedTabsManager.recordBrowser(browser, index)
         
+        browser.closeWebInspector()
         browser.home()
         self.removeTab(index)
         self.browserClosed.emit(browser)
+        browser.deleteLater()
         del browser
         
         if self.count() == 0:
@@ -668,7 +689,7 @@ class HelpTabWidget(E5TabWidget):
         """
         browser = self.sender()
         
-        if browser is not None:
+        if browser is not None and isinstance(browser, QWidget):
             index = self.indexOf(browser)
             if title == "":
                 title = browser.url().toString()
@@ -775,7 +796,7 @@ class HelpTabWidget(E5TabWidget):
         """
         browser = self.sender()
         
-        if browser is not None:
+        if browser is not None and isinstance(browser, QWidget):
             import Helpviewer.HelpWindow
             self.setTabIcon(
                 self.indexOf(browser),
